/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * Copyright (C) 2022 New Zealand Digital Library Project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
package org.greenstone.gatherer.cdm;

import org.greenstone.gatherer.util.StaticStrings;
import org.w3c.dom.*;

/** handles sortfields for lucene and solr collections */
public class SortFieldManager extends BaseIndexManager {

    public SortFieldManager(Element sortfields, String current_build_type) {
	super(sortfields, current_build_type, StaticStrings.SORT_ELEMENT, StaticStrings.SORT_DEFAULT_ELEMENT, new SortField());
	this.controls_title_key = "CDM.SortFieldManager.Title";
	this.new_button_tooltip_key = "CDM.SortFieldManager.New_Button_Tooltip";
	this.edit_button_tooltip_key = "CDM.SortFieldManager.Edit_Button_Tooltip";
	this.remove_button_tooltip_key = "CDM.SortFieldManager.Remove_Button_Tooltip";
        this.default_indicator_key = "CDM.SortFieldManager.Default_Sort_Indicator";
        this.set_default_tooltip_key = "CDM.SortFieldManager.Set_Default_Tooltip";
	this.nip_new_index_key = "CDM.SortFieldManager.New";
	this.nip_edit_index_key = "CDM.SortFieldManager.Edit";
	this.nip_source_label_key = "CDM.SortFieldManager.Source";
        this.nip_source_tooltip_key = "CDM.SortFieldManager.Source_Tooltip";

	this.nip_add_index_button_key = "CDM.SortFieldManager.Add";
	this.nip_add_index_tooltip_key = "CDM.SortFieldManager.Add_Tooltip";
	this.nip_replace_index_button_key = "CDM.SortFieldManager.Replace";
	this.nip_replace_index_tooltip_key = "CDM.SortFieldManager.Replace_Tooltip";
    }

    public void buildTypeChanged(String new_build_type) {
	if (new_build_type.equals(BuildTypeManager.BUILD_TYPE_SOLR)|| new_build_type.equals(BuildTypeManager.BUILD_TYPE_LUCENE)) {
	    // activate
	    setAssigned(true);
	} else {
	    // deactivate
	    setAssigned(false);
	}
    }

}
